tags

package
v0.0.0-...-e3e3546 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 18, 2025 License: BSD-3-Clause Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SetLocalTagsAsync

func SetLocalTagsAsync(tmpl *event.Event)

SetLocalTagsAsync fetches information about the local machine and sets tags on the given the event template. Since it requires network requests to fetch things like IMDS, it should be called in a separate goroutine.

Types

This section is empty.

Directories

Path Synopsis

Jump to