Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func SetLocalTagsAsync ¶
SetLocalTagsAsync fetches information about the local machine and sets tags on the given the event template. Since it requires network requests to fetch things like IMDS, it should be called in a separate goroutine.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.